==> fdo-3.2.2.tar.gz: OpenSource_FDO/Thirdparty/cppunit/include/msvc6/dsplugin/TestRunnerDSPlugin_i.c <==


/* this ALWAYS GENERATED file contains the IIDs and CLSIDs */

/* link this file in with the server and any clients */


 /* File created by MIDL compiler version 6.00.0361 */
/* at Fri Aug 22 09:23:13 2003
 */
/* Compiler settings for TestRunnerDSPlugin.idl:
    Oicf, W1, Zp8, env=Win32 (32b run)
    protocol : dce , ms_ext, c_ext, robust
    error checks: allocation ref bounds_check enum stub_data 
    VC __declspec() decoration level: 
         __declspec(uuid()), __declspec(selectany), __declspec(novtable)
         DECLSPEC_UUID(), MIDL_INTERFACE()
*/
//@@MIDL_FILE_HEADING(  )

#if !defined(_M_IA64) && !defined(_M_AMD64)


#pragma warning( disable: 4049 )  /* more than 64k source lines */


#ifdef __cplusplus
extern "C"{
#endif 


#include <rpc.h>
#include <rpcndr.h>

#ifdef _MIDL_USE_GUIDDEF_

#ifndef INITGUID
#define INITGUID
#include <guiddef.h>
#undef INITGUID
#else
#include <guiddef.h>
#endif

#define MIDL_DEFINE_GUID(type,name,l,w1,w2,b1,b2,b3,b4,b5,b6,b7,b8) \
        DEFINE_GUID(name,l,w1,w2,b1,b2,b3,b4,b5,b6,b7,b8)

#else // !_MIDL_USE_GUIDDEF_

#ifndef __IID_DEFINED__
#define __IID_DEFINED__

typedef struct _IID
{
    unsigned long x;
    unsigned short s1;
    unsigned short s2;
    unsigned char  c[8];
} IID;

#endif // __IID_DEFINED__

#ifndef CLSID_DEFINED
#define CLSID_DEFINED
typedef IID CLSID;
#endif // CLSID_DEFINED

#define MIDL_DEFINE_GUID(type,name,l,w1,w2,b1,b2,b3,b4,b5,b6,b7,b8) \
        const type name = {l,w1,w2,{b1,b2,b3,b4,b5,b6,b7,b8}}

#endif !_MIDL_USE_GUIDDEF_

MIDL_DEFINE_GUID(IID, IID_ITestRunnerDSPlugin,0x3ADE0E37,0x5A56,0x4a68,0xBD,0x8D,0x67,0xE9,0xE7,0x50,0x29,0x71);


MIDL_DEFINE_GUID(IID, LIBID_TestRunnerDSPluginLib,0x3ADE0E38,0x5A56,0x4a68,0xBD,0x8D,0x67,0xE9,0xE7,0x50,0x29,0x71);


MIDL_DEFINE_GUID(CLSID, CLSID_DSAddIn,0xF193CE54,0x716C,0x41CB,0x80,0xB2,0xFA,0x74,0xCA,0x3E,0xE2,0xAC);

#undef MIDL_DEFINE_GUID

#ifdef __cplusplus
}
#endif



#endif /* !defined(_M_IA64) && !defined(_M_AMD64)*/

==> fdo-3.9.0_5601.tar.gz: OpenSource_FDO/Thirdparty/cppunit/include/msvc6/dsplugin/TestRunnerDSPlugin_i.c <==


/* this ALWAYS GENERATED file contains the IIDs and CLSIDs */

/* link this file in with the server and any clients */


 /* File created by MIDL compiler version 6.00.0361 */
/* at Fri Aug 22 09:23:13 2003
 */
/* Compiler settings for TestRunnerDSPlugin.idl:
    Oicf, W1, Zp8, env=Win32 (32b run)
    protocol : dce , ms_ext, c_ext, robust
    error checks: allocation ref bounds_check enum stub_data 
    VC __declspec() decoration level: 
         __declspec(uuid()), __declspec(selectany), __declspec(novtable)
         DECLSPEC_UUID(), MIDL_INTERFACE()
*/
//@@MIDL_FILE_HEADING(  )

//#if !defined(_M_IA64) && !defined(_M_AMD64)


#pragma warning( disable: 4049 )  /* more than 64k source lines */


#ifdef __cplusplus
extern "C"{
#endif 


#include <rpc.h>
#include <rpcndr.h>

#ifdef _MIDL_USE_GUIDDEF_

#ifndef INITGUID
#define INITGUID
#include <guiddef.h>
#undef INITGUID
#else
#include <guiddef.h>
#endif

#define MIDL_DEFINE_GUID(type,name,l,w1,w2,b1,b2,b3,b4,b5,b6,b7,b8) \
        DEFINE_GUID(name,l,w1,w2,b1,b2,b3,b4,b5,b6,b7,b8)

#else // !_MIDL_USE_GUIDDEF_

#ifndef __IID_DEFINED__
#define __IID_DEFINED__

typedef struct _IID
{
    unsigned long x;
    unsigned short s1;
    unsigned short s2;
    unsigned char  c[8];
} IID;

#endif // __IID_DEFINED__

#ifndef CLSID_DEFINED
#define CLSID_DEFINED
typedef IID CLSID;
#endif // CLSID_DEFINED

#define MIDL_DEFINE_GUID(type,name,l,w1,w2,b1,b2,b3,b4,b5,b6,b7,b8) \
        const type name = {l,w1,w2,{b1,b2,b3,b4,b5,b6,b7,b8}}

#endif !_MIDL_USE_GUIDDEF_

MIDL_DEFINE_GUID(IID, IID_ITestRunnerDSPlugin,0x3ADE0E37,0x5A56,0x4a68,0xBD,0x8D,0x67,0xE9,0xE7,0x50,0x29,0x71);


MIDL_DEFINE_GUID(IID, LIBID_TestRunnerDSPluginLib,0x3ADE0E38,0x5A56,0x4a68,0xBD,0x8D,0x67,0xE9,0xE7,0x50,0x29,0x71);


MIDL_DEFINE_GUID(CLSID, CLSID_DSAddIn,0xF193CE54,0x716C,0x41CB,0x80,0xB2,0xFA,0x74,0xCA,0x3E,0xE2,0xAC);

#undef MIDL_DEFINE_GUID

#ifdef __cplusplus
}
#endif



//#endif /* !defined(_M_IA64) && !defined(_M_AMD64)*/
